twill: a simple scripting language for web browsing
===================================================

twill is a simple scripting language intended for programmatic or automated browsing of websites.

The current version 3.0.1 supports Python 3.6 to 3.10.

See also the [changelog](https://twill-tools.github.io/twill/changelog.html) for a summary of the things that have been changed and improved since version 2.0, and the [acknowledgements](https://twill-tools.github.io/twill/overview.html#acknowledgements) for a short overview of the earlier history of twill.

The full [documentation](https://twill-tools.github.io/twill/) is included in the distribution and provided online.

Copyright (c) by C. Titus Brown et al.

Newer versions have been created and are maintained by [Christoph Zwerschke](https://github.com/Cito).
 
twill is available for use, modification, and distribution under the MIT license.
